# -*- coding: utf-8

"""Wrapper for PaDEL descriptors"""

from .padel_wrapper import PaDEL
from .descriptor import descriptors

__version__ = "1.0.0-post2"
